==> ros-rviz_1.14.19+dfsg.orig.tar.xz: rviz-1.14.19/src/rviz/properties/float_edit.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <QDoubleValidator>
#include <QLocale>

#include <rviz/properties/float_edit.h>

namespace rviz
{
FloatEdit::FloatEdit(QWidget* parent) : QLineEdit(parent)
{
  setFrame(false);
  setValidator(new QDoubleValidator(this));
  connect(this, SIGNAL(textEdited(const QString&)), this, SLOT(updateValue()));
}

void FloatEdit::setValue(float new_value)
{
  if (value_ != new_value)
  {
    QLocale locale;
    value_ = new_value;
    bool ok = true;
    float existing_text_value = locale.toFloat(text(), &ok);
    if (!ok || existing_text_value != new_value)
    {
      setText(locale.toString((double)value_));
    }
  }
}

void FloatEdit::updateValue()
{
  if (hasAcceptableInput())
  {
    bool ok = true;
    float new_value = QLocale().toFloat(text(), &ok);
    if (ok)
    {
      setValue(new_value);
    }
  }
}

} // end namespace rviz

==> ros-rviz_1.14.25+dfsg.orig.tar.xz: rviz-1.14.25/src/rviz/properties/float_edit.cpp <==
/*
 * Copyright (c) 2012, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <QDoubleValidator>
#include <QLocale>

#include <rviz/properties/float_edit.h>

namespace rviz
{
FloatEdit::FloatEdit(QWidget* parent) : QLineEdit(parent)
{
  setFrame(false);
  setValidator(new QDoubleValidator(this));
  connect(this, &FloatEdit::textEdited, this, &FloatEdit::updateValue);
}

void FloatEdit::setValue(float new_value)
{
  if (value_ != new_value)
  {
    QLocale locale;
    value_ = new_value;
    bool ok = true;
    float existing_text_value = locale.toFloat(text(), &ok);
    if (!ok || existing_text_value != new_value)
    {
      setText(locale.toString((double)value_));
    }
  }
}

void FloatEdit::updateValue()
{
  if (hasAcceptableInput())
  {
    bool ok = true;
    float new_value = QLocale().toFloat(text(), &ok);
    if (ok)
    {
      setValue(new_value);
    }
  }
}

} // end namespace rviz
